aboutsummaryrefslogtreecommitdiff
path: root/src/libjin/Graphics/je_shapes.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/libjin/Graphics/je_shapes.cpp')
-rw-r--r--src/libjin/Graphics/je_shapes.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/libjin/Graphics/je_shapes.cpp b/src/libjin/Graphics/je_shapes.cpp
index 31c793f..5a6dee8 100644
--- a/src/libjin/Graphics/je_shapes.cpp
+++ b/src/libjin/Graphics/je_shapes.cpp
@@ -9,12 +9,12 @@
#include "shader/je_shader.h"
#include "je_shapes.h"
-namespace jin
+namespace JinEngine
{
- namespace graphics
+ namespace Graphics
{
- using namespace math;
+ using namespace Math;
void point(int x, int y)
{
@@ -122,7 +122,7 @@ namespace jin
}
}
- } // namespace graphics
-} // namespace jin
+ } // namespace Graphics
+} // namespace JinEngine
#endif // LIBJIN_MODULES_RENDER \ No newline at end of file